@@ -530,7 +530,7 @@ def form_detail(request, slug, template="forms/form_detail.html"):
 
             # default redirect
             if form.completion_url:
-                return redirect(form.completion_url)
+                return HttpResponseRedirect(form.completion_url)
             return redirect("form_sent", form.slug)
     # set form's template to default if no template or template doesn't exist
     if not form.template or not template_exists(form.template):
